==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/Extension__24Value.h <==
// public class gnu.java.security.x509.ext.Extension$Value

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_ext_Extension__24Value_H_
#define _JC_gnu_java_security_x509_ext_Extension__24Value_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	_jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	_jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$refs	_jc_gnu_java_security_x509_ext_Extension__24Value$refs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs	_jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$object	_jc_gnu_java_security_x509_ext_Extension__24Value$object;

typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtable	_jc_gnu_java_security_x509_ext_Extension__24Value$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtype	_jc_gnu_java_security_x509_ext_Extension__24Value$vtype;

// Constructors
extern void _jc_gnu_java_security_x509_ext_Extension__24Value$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *);
extern void _jc_gnu_java_security_x509_ext_Extension__24Value$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_byte_array *);

// Virtual methods
extern jboolean _jc_gnu_java_security_x509_ext_Extension__24Value$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_java_lang_Object$object *);
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_Extension__24Value$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_Extension__24Value$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_java_lang_Object$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs {
	_jc_byte_array	*encoded;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$refs {
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_Extension__24Value$object {
	_jc_gnu_java_security_x509_ext_Extension__24Value$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_Extension__24Value$vtype _jc_gnu_java_security_x509_ext_Extension__24Value$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_Extension__24Value, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_Extension__24Value$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_Extension__24Value_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/Extension__24Value.h <==
// public class gnu.java.security.x509.ext.Extension$Value

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_ext_Extension__24Value_H_
#define _JC_gnu_java_security_x509_ext_Extension__24Value_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	_jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	_jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$refs	_jc_gnu_java_security_x509_ext_Extension__24Value$refs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs	_jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_Extension__24Value$object	_jc_gnu_java_security_x509_ext_Extension__24Value$object;

typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtable	_jc_gnu_java_security_x509_ext_Extension__24Value$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtype	_jc_gnu_java_security_x509_ext_Extension__24Value$vtype;

// Constructors
extern void _jc_gnu_java_security_x509_ext_Extension__24Value$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_ext_Extension__24Value$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_security_x509_ext_Extension__24Value$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_Extension__24Value$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_Extension__24Value$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_Extension__24Value$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_Extension__24Value$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_Extension__24Value$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs {
	_jc_byte_array	*encoded;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$refs {
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_Extension__24Value$object {
	_jc_gnu_java_security_x509_ext_Extension__24Value$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_Extension__24Value$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_Extension__24Value$vtype _jc_gnu_java_security_x509_ext_Extension__24Value$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_Extension__24Value, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_Extension__24Value$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_Extension__24Value_H_ */
